==> gambit-v4_9_5.tgz: gambit-v4_9_5/tests/unit-tests/13-modules/prim_list.scm <==
(include "#.scm")

(check-same-behavior ("" "##" "~~lib/gambit/prim/list#.scm")

;; R4RS

(append) (append '(1 2)) (append '(1 2) '(3 4)) (append '(1 2) '(3 4) '(5 6))
(assoc "a" '()) (assoc "a" '(("a" . 1))) (assoc "a" '(("a" . 1)) eq?)
(assq 'a '()) (assq 'a '((a . 1)))
(assv 1 '()) (assv 1 '((1 . 2)))
(caaaar '(((((a . b) c . d) (e . f) g . h) ((i . j) k . l) (m . n) o . p)
          (((q . r) s . t) (u . v) w . x) ((y . z) 0 . 1) (2 . 3) 4 . 5))
(caaadr '(((((a . b) c . d) (e . f) g . h) ((i . j) k . l) (m . n) o . p)
          (((q . r) s . t) (u . v) w . x) ((y . z) 0 . 1) (2 . 3) 4 . 5))
(caaar '(((((a . b) c . d) (e . f) g . h) ((i . j) k . l) (m . n) o . p)
         (((q . r) s . t) (u . v) w . x) ((y . z) 0 . 1) (2 . 3) 4 . 5))
(caadar '(((((a . b) c . d) (e . f) g . h) ((i . j) k . l) (m . n) o . p)
          (((q . r) s . t) (u . v) w . x) ((y . z) 0 . 1) (2 . 3) 4 . 5))
(caaddr '(((((a . b) c . d) (e . f) g . h) ((i . j) k . l) (m . n) o . p)
          (((q . r) s . t) (u . v) w . x) ((y . z) 0 . 1) (2 . 3) 4 . 5))
(caadr '(((((a . b) c . d) (e . f) g . h) ((i . j) k . l) (m . n) o . p)
         (((q . r) s . t) (u . v) w . x) ((y . z) 0 . 1) (2 . 3) 4 . 5))
(caar '(((((a . b) c . d) (e . f) g . h) ((i . j) k . l) (m . n) o . p)
        (((q . r) s . t) (u . v) w . x) ((y . z) 0 . 1) (2 . 3) 4 . 5))
(cadaar '(((((a . b) c . d) (e . f) g . h) ((i . j) k . l) (m . n) o . p)
          (((q . r) s . t) (u . v) w . x) ((y . z) 0 . 1) (2 . 3) 4 . 5))
(cadadr '(((((a . b) c . d) (e . f) g . h) ((i . j) k . l) (m . n) o . p)
          (((q . r) s . t) (u . v) w . x) ((y . z) 0 . 1) (2 . 3) 4 . 5))
(cadar '(((((a . b) c . d) (e . f) g . h) ((i . j) k . l) (m . n) o . p)
         (((q . r) s . t) (u . v) w . x) ((y . z) 0 . 1) (2 . 3) 4 . 5))
(caddar '(((((a . b) c . d) (e . f) g . h) ((i . j) k . l) (m . n) o . p)
          (((q . r) s . t) (u . v) w . x) ((y . z) 0 . 1) (2 . 3) 4 . 5))
(cadddr '(((((a . b) c . d) (e . f) g . h) ((i . j) k . l) (m . n) o . p)
          (((q . r) s . t) (u . v) w . x) ((y . z) 0 . 1) (2 . 3) 4 . 5))
(caddr '(((((a . b) c . d) (e . f) g . h) ((i . j) k . l) (m . n) o . p)
         (((q . r) s . t) (u . v) w . x) ((y . z) 0 . 1) (2 . 3) 4 . 5))
(cadr '(((((a . b) c . d) (e . f) g . h) ((i . j) k . l) (m . n) o . p)
        (((q . r) s . t) (u . v) w . x) ((y . z) 0 . 1) (2 . 3) 4 . 5))
(car '(((((a . b) c . d) (e . f) g . h) ((i . j) k . l) (m . n) o . p)
       (((q . r) s . t) (u . v) w . x) ((y . z) 0 . 1) (2 . 3) 4 . 5))
(cdaaar '(((((a . b) c . d) (e . f) g . h) ((i . j) k . l) (m . n) o . p)
          (((q . r) s . t) (u . v) w . x) ((y . z) 0 . 1) (2 . 3) 4 . 5))
(cdaadr '(((((a . b) c . d) (e . f) g . h) ((i . j) k . l) (m . n) o . p)
          (((q . r) s . t) (u . v) w . x) ((y . z) 0 . 1) (2 . 3) 4 . 5))
(cdaar '(((((a . b) c . d) (e . f) g . h) ((i . j) k . l) (m . n) o . p)
         (((q . r) s . t) (u . v) w . x) ((y . z) 0 . 1) (2 . 3) 4 . 5))
(cdadar '(((((a . b) c . d) (e . f) g . h) ((i . j) k . l) (m . n) o . p)
          (((q . r) s . t) (u . v) w . x) ((y . z) 0 . 1) (2 . 3) 4 . 5))
(cdaddr '(((((a . b) c . d) (e . f) g . h) ((i . j) k . l) (m . n) o . p)
          (((q . r) s . t) (u . v) w . x) ((y . z) 0 . 1) (2 . 3) 4 . 5))
(cdadr '(((((a . b) c . d) (e . f) g . h) ((i . j) k . l) (m . n) o . p)
         (((q . r) s . t) (u . v) w . x) ((y . z) 0 . 1) (2 . 3) 4 . 5))
(cdar '(((((a . b) c . d) (e . f) g . h) ((i . j) k . l) (m . n) o . p)
        (((q . r) s . t) (u . v) w . x) ((y . z) 0 . 1) (2 . 3) 4 . 5))
(cddaar '(((((a . b) c . d) (e . f) g . h) ((i . j) k . l) (m . n) o . p)
          (((q . r) s . t) (u . v) w . x) ((y . z) 0 . 1) (2 . 3) 4 . 5))
(cddadr '(((((a . b) c . d) (e . f) g . h) ((i . j) k . l) (m . n) o . p)
          (((q . r) s . t) (u . v) w . x) ((y . z) 0 . 1) (2 . 3) 4 . 5))
(cddar '(((((a . b) c . d) (e . f) g . h) ((i . j) k . l) (m . n) o . p)
         (((q . r) s . t) (u . v) w . x) ((y . z) 0 . 1) (2 . 3) 4 . 5))
(cdddar '(((((a . b) c . d) (e . f) g . h) ((i . j) k . l) (m . n) o . p)
          (((q . r) s . t) (u . v) w . x) ((y . z) 0 . 1) (2 . 3) 4 . 5))
(cddddr '(((((a . b) c . d) (e . f) g . h) ((i . j) k . l) (m . n) o . p)
          (((q . r) s . t) (u . v) w . x) ((y . z) 0 . 1) (2 . 3) 4 . 5))
(cdddr '(((((a . b) c . d) (e . f) g . h) ((i . j) k . l) (m . n) o . p)
         (((q . r) s . t) (u . v) w . x) ((y . z) 0 . 1) (2 . 3) 4 . 5))
(cddr '(((((a . b) c . d) (e . f) g . h) ((i . j) k . l) (m . n) o . p)
        (((q . r) s . t) (u . v) w . x) ((y . z) 0 . 1) (2 . 3) 4 . 5))
(cdr '(((((a . b) c . d) (e . f) g . h) ((i . j) k . l) (m . n) o . p)
       (((q . r) s . t) (u . v) w . x) ((y . z) 0 . 1) (2 . 3) 4 . 5))
(cons 1 2)
(for-each list '(1 2)) (for-each list '(1) '(2)) (for-each list '(1) '(2) '(3))
(length '(1 2 3))
(list) (list 1) (list 1 2) (list 1 2 3)
(list-ref '(1 2 3) 1)
(list-tail '(1 2 3) 1)
(list? '()) (list? '(1 2 3)) (list '(1 . 2))
(map list '(1 2)) (map list '(1) '(2)) (map list '(1) '(2) '(3))
(member "a" '()) (member "a" '("a" "b")) (member "a" '("a" "b") eq?)
(memq 'a '()) (memq 'a '(a b))
(memv '1 '()) (memv '1 '(1 2))
(null? '()) (null? '(1 2))
(pair? '()) (pair? '(1 2))
(reverse '()) (reverse '(1 2 3))
(let ((x (cons 1 2))) (set-car! x 3) x)
(let ((x (cons 1 2))) (set-cdr! x 3) x)

;; R7RS

(make-list 0) (make-list 5) (make-list 5 99)
(list-copy '()) (list-copy '(1 2 3))
(list-set! (list 1 2 3) 1 99)

;; Gambit

(call-with-values (lambda () (car+cdr '(1 2 3))) (lambda (a b) (list a b)))
(list-ref (circular-list 1) 10) (list-ref (circular-list 1 2) 10) (list-ref (circular-list 1 2 3) 10)
(circular-list? '(1 2 3)) (circular-list? (circular-list 1 2 3))
(concatenate '((1 2) (3 4) 5))
(let ((a (list 1 2)) (b (list 3 4))) (list a b (concatenate! (list a b 5))))
(cons* 1) (cons* 1 2) (cons* 1 2 3)
(dotted-list? '(1 2 3)) (dotted-list? '(1 2 . 3))
(drop '(1 2 3 4) 2)
(filter odd? '(1 2 3 4 5))
(fold list 1 '(2 3 4 5))
(fold-right list 1 '(2 3 4 5))
(iota 10)
(last '(1 2 3 4))
(last-pair '(1 2 3 4))
(length+ '()) (length+ '(1 2 3)) (length+ (circular-list 1 2 3))
(list-set '(1 2 3 4) 2 99)
(let ((x (list))) (list-sort < x)) (let ((x (list 8 3 1 2 4))) (list-sort < x))
(let ((x (list))) (list-sort! < x)) (let ((x (list 8 3 1 2 4))) (list-sort! < x))
(list-tabulate 5 list)
(not-pair? '()) (not-pair? '(1 2 3))
(null-list? '()) (null-list? '(1 2 3))
(proper-list? '()) (proper-list? '(1 2 3)) (proper-list? '(1 2 . 3))
(remove odd? '(1 2 3 4))
(remq 'b '(a b c))
(let ((x (list 1 2 3 4))) (reverse! x))
(let ((x (list 1 2 3 4))) (append-reverse x 5))
(let ((x (list 1 2 3 4))) (append-reverse! x 5))
(take '(1 2 3 4) 2)
(xcons 1 2)

(first '(1 2 3 4 5 6 7 8 9 10 11))
(second '(1 2 3 4 5 6 7 8 9 10 11))
(third '(1 2 3 4 5 6 7 8 9 10 11))
(fourth '(1 2 3 4 5 6 7 8 9 10 11))
(fifth '(1 2 3 4 5 6 7 8 9 10 11))
(sixth '(1 2 3 4 5 6 7 8 9 10 11))
(seventh '(1 2 3 4 5 6 7 8 9 10 11))
(eighth '(1 2 3 4 5 6 7 8 9 10 11))
(ninth '(1 2 3 4 5 6 7 8 9 10 11))
(tenth '(1 2 3 4 5 6 7 8 9 10 11))

)

==> gambit-v4_9_7.tgz: gambit-v4_9_7/tests/unit-tests/13-modules/prim_list.scm <==
(include "#.scm")

(check-same-behavior ("" "##" "~~lib/gambit/prim/list#.scm")

;; R4RS

(append!) (append! (list 1 2)) (append! (list 1 2) (list 3 4)) (append! (list 1 2) (list 3 4) (list 5 6))
(append) (append '(1 2)) (append '(1 2) '(3 4)) (append '(1 2) '(3 4) '(5 6))
(assoc "a" '()) (assoc "a" '(("a" . 1))) (assoc "a" '(("a" . 1)) eq?)
(assq 'a '()) (assq 'a '((a . 1)))
(assv 1 '()) (assv 1 '((1 . 2)))
(caaaar '(((((a . b) c . d) (e . f) g . h) ((i . j) k . l) (m . n) o . p)
          (((q . r) s . t) (u . v) w . x) ((y . z) 0 . 1) (2 . 3) 4 . 5))
(caaadr '(((((a . b) c . d) (e . f) g . h) ((i . j) k . l) (m . n) o . p)
          (((q . r) s . t) (u . v) w . x) ((y . z) 0 . 1) (2 . 3) 4 . 5))
(caaar '(((((a . b) c . d) (e . f) g . h) ((i . j) k . l) (m . n) o . p)
         (((q . r) s . t) (u . v) w . x) ((y . z) 0 . 1) (2 . 3) 4 . 5))
(caadar '(((((a . b) c . d) (e . f) g . h) ((i . j) k . l) (m . n) o . p)
          (((q . r) s . t) (u . v) w . x) ((y . z) 0 . 1) (2 . 3) 4 . 5))
(caaddr '(((((a . b) c . d) (e . f) g . h) ((i . j) k . l) (m . n) o . p)
          (((q . r) s . t) (u . v) w . x) ((y . z) 0 . 1) (2 . 3) 4 . 5))
(caadr '(((((a . b) c . d) (e . f) g . h) ((i . j) k . l) (m . n) o . p)
         (((q . r) s . t) (u . v) w . x) ((y . z) 0 . 1) (2 . 3) 4 . 5))
(caar '(((((a . b) c . d) (e . f) g . h) ((i . j) k . l) (m . n) o . p)
        (((q . r) s . t) (u . v) w . x) ((y . z) 0 . 1) (2 . 3) 4 . 5))
(cadaar '(((((a . b) c . d) (e . f) g . h) ((i . j) k . l) (m . n) o . p)
          (((q . r) s . t) (u . v) w . x) ((y . z) 0 . 1) (2 . 3) 4 . 5))
(cadadr '(((((a . b) c . d) (e . f) g . h) ((i . j) k . l) (m . n) o . p)
          (((q . r) s . t) (u . v) w . x) ((y . z) 0 . 1) (2 . 3) 4 . 5))
(cadar '(((((a . b) c . d) (e . f) g . h) ((i . j) k . l) (m . n) o . p)
         (((q . r) s . t) (u . v) w . x) ((y . z) 0 . 1) (2 . 3) 4 . 5))
(caddar '(((((a . b) c . d) (e . f) g . h) ((i . j) k . l) (m . n) o . p)
          (((q . r) s . t) (u . v) w . x) ((y . z) 0 . 1) (2 . 3) 4 . 5))
(cadddr '(((((a . b) c . d) (e . f) g . h) ((i . j) k . l) (m . n) o . p)
          (((q . r) s . t) (u . v) w . x) ((y . z) 0 . 1) (2 . 3) 4 . 5))
(caddr '(((((a . b) c . d) (e . f) g . h) ((i . j) k . l) (m . n) o . p)
         (((q . r) s . t) (u . v) w . x) ((y . z) 0 . 1) (2 . 3) 4 . 5))
(cadr '(((((a . b) c . d) (e . f) g . h) ((i . j) k . l) (m . n) o . p)
        (((q . r) s . t) (u . v) w . x) ((y . z) 0 . 1) (2 . 3) 4 . 5))
(car '(((((a . b) c . d) (e . f) g . h) ((i . j) k . l) (m . n) o . p)
       (((q . r) s . t) (u . v) w . x) ((y . z) 0 . 1) (2 . 3) 4 . 5))
(cdaaar '(((((a . b) c . d) (e . f) g . h) ((i . j) k . l) (m . n) o . p)
          (((q . r) s . t) (u . v) w . x) ((y . z) 0 . 1) (2 . 3) 4 . 5))
(cdaadr '(((((a . b) c . d) (e . f) g . h) ((i . j) k . l) (m . n) o . p)
          (((q . r) s . t) (u . v) w . x) ((y . z) 0 . 1) (2 . 3) 4 . 5))
(cdaar '(((((a . b) c . d) (e . f) g . h) ((i . j) k . l) (m . n) o . p)
         (((q . r) s . t) (u . v) w . x) ((y . z) 0 . 1) (2 . 3) 4 . 5))
(cdadar '(((((a . b) c . d) (e . f) g . h) ((i . j) k . l) (m . n) o . p)
          (((q . r) s . t) (u . v) w . x) ((y . z) 0 . 1) (2 . 3) 4 . 5))
(cdaddr '(((((a . b) c . d) (e . f) g . h) ((i . j) k . l) (m . n) o . p)
          (((q . r) s . t) (u . v) w . x) ((y . z) 0 . 1) (2 . 3) 4 . 5))
(cdadr '(((((a . b) c . d) (e . f) g . h) ((i . j) k . l) (m . n) o . p)
         (((q . r) s . t) (u . v) w . x) ((y . z) 0 . 1) (2 . 3) 4 . 5))
(cdar '(((((a . b) c . d) (e . f) g . h) ((i . j) k . l) (m . n) o . p)
        (((q . r) s . t) (u . v) w . x) ((y . z) 0 . 1) (2 . 3) 4 . 5))
(cddaar '(((((a . b) c . d) (e . f) g . h) ((i . j) k . l) (m . n) o . p)
          (((q . r) s . t) (u . v) w . x) ((y . z) 0 . 1) (2 . 3) 4 . 5))
(cddadr '(((((a . b) c . d) (e . f) g . h) ((i . j) k . l) (m . n) o . p)
          (((q . r) s . t) (u . v) w . x) ((y . z) 0 . 1) (2 . 3) 4 . 5))
(cddar '(((((a . b) c . d) (e . f) g . h) ((i . j) k . l) (m . n) o . p)
         (((q . r) s . t) (u . v) w . x) ((y . z) 0 . 1) (2 . 3) 4 . 5))
(cdddar '(((((a . b) c . d) (e . f) g . h) ((i . j) k . l) (m . n) o . p)
          (((q . r) s . t) (u . v) w . x) ((y . z) 0 . 1) (2 . 3) 4 . 5))
(cddddr '(((((a . b) c . d) (e . f) g . h) ((i . j) k . l) (m . n) o . p)
          (((q . r) s . t) (u . v) w . x) ((y . z) 0 . 1) (2 . 3) 4 . 5))
(cdddr '(((((a . b) c . d) (e . f) g . h) ((i . j) k . l) (m . n) o . p)
         (((q . r) s . t) (u . v) w . x) ((y . z) 0 . 1) (2 . 3) 4 . 5))
(cddr '(((((a . b) c . d) (e . f) g . h) ((i . j) k . l) (m . n) o . p)
        (((q . r) s . t) (u . v) w . x) ((y . z) 0 . 1) (2 . 3) 4 . 5))
(cdr '(((((a . b) c . d) (e . f) g . h) ((i . j) k . l) (m . n) o . p)
       (((q . r) s . t) (u . v) w . x) ((y . z) 0 . 1) (2 . 3) 4 . 5))
(cons 1 2)
(for-each list '(1 2)) (for-each list '(1) '(2)) (for-each list '(1) '(2) '(3))
(length '(1 2 3))
(list) (list 1) (list 1 2) (list 1 2 3)
(list-ref '(1 2 3) 1)
(list-tail '(1 2 3) 1)
(list? '()) (list? '(1 2 3)) (list '(1 . 2))
(map list '(1 2)) (map list '(1) '(2)) (map list '(1) '(2) '(3))
(member "a" '()) (member "a" '("a" "b")) (member "a" '("a" "b") eq?)
(memq 'a '()) (memq 'a '(a b))
(memv '1 '()) (memv '1 '(1 2))
(null? '()) (null? '(1 2))
(pair? '()) (pair? '(1 2))
(reverse '()) (reverse '(1 2 3))
(let ((x (cons 1 2))) (set-car! x 3) x)
(let ((x (cons 1 2))) (set-cdr! x 3) x)

;; R7RS

(make-list 0) (make-list 5) (make-list 5 99)
(list-copy '()) (list-copy '(1 2 3))
(list-set! (list 1 2 3) 1 99)

;; Gambit

(any odd? '()) (any odd? '(2 4)) (any odd? '(1 2)) (any odd? '(2 1)) (any < '(5 5 5) '(4 7 9) '(1 6 13))
(call-with-values (lambda () (car+cdr '(1 2 3))) (lambda (a b) (list a b)))
(list-ref (circular-list 1) 10) (list-ref (circular-list 1 2) 10) (list-ref (circular-list 1 2 3) 10)
(circular-list? '(1 2 3)) (circular-list? (circular-list 1 2 3))
(concatenate '((1 2) (3 4) 5))
(let ((a (list 1 2)) (b (list 3 4))) (list a b (concatenate! (list a b 5))))
(cons* 1) (cons* 1 2) (cons* 1 2 3)
(dotted-list? '(1 2 3)) (dotted-list? '(1 2 . 3))
(drop '(1 2 3 4) 2)
(drop-right '(1 2 3 4) 2)
(drop-right! (list 1 2 3 4) 2)
(every odd? '()) (every odd? '(2 4)) (every odd? '(1 2)) (every odd? '(2 1)) (every < '(5 5 5) '(4 7 9) '(1 6 13))
(filter odd? '(1 2 3 4 5))
(delete 3 '(1 2 3 4 5))(delete 3 (list 1 2 3 4 5) <)
(fold list 1 '(2 3 4 5))
(fold-right list 1 '(2 3 4 5))
(iota 10)
(last '(1 2 3 4))
(last-pair '(1 2 3 4))
(length+ '()) (length+ '(1 2 3)) (length+ (circular-list 1 2 3))
(list-set '(1 2 3 4) 2 99)
(let ((x (list))) (list-sort < x)) (let ((x (list 8 3 1 2 4))) (list-sort < x))
(let ((x (list))) (list-sort! < x)) (let ((x (list 8 3 1 2 4))) (list-sort! < x))
(list-tabulate 5 list)
(not-pair? '()) (not-pair? '(1 2 3))
(null-list? '()) (null-list? '(1 2 3))
(call-with-values (lambda () (partition! odd? (list 1 2 3 4 5))) (lambda (a b) (list a b)))
(call-with-values (lambda () (partition odd? '(1 2 3 4 5))) (lambda (a b) (list a b)))
(proper-list? '()) (proper-list? '(1 2 3)) (proper-list? '(1 2 . 3))
(remove odd? '(1 2 3 4))
(remq 'b '(a b c))
(let ((x (list 1 2 3 4))) (reverse! x))
(let ((x (list 1 2 3 4))) (append-reverse x 5))
(let ((x (list 1 2 3 4))) (append-reverse! x 5))
(take '(1 2 3 4) 2)
(take! (list 1 2 3 4) 2)
(take-right '(1 2 3 4) 2)
(call-with-values (lambda () (split-at '(1 2 3 4) 1)) (lambda (a b) (list a b)))
(call-with-values (lambda () (split-at! (list 1 2 3 4) 1)) (lambda (a b) (list a b)))
(xcons 1 2)

(first '(1 2 3 4 5 6 7 8 9 10 11))
(second '(1 2 3 4 5 6 7 8 9 10 11))
(third '(1 2 3 4 5 6 7 8 9 10 11))
(fourth '(1 2 3 4 5 6 7 8 9 10 11))
(fifth '(1 2 3 4 5 6 7 8 9 10 11))
(sixth '(1 2 3 4 5 6 7 8 9 10 11))
(seventh '(1 2 3 4 5 6 7 8 9 10 11))
(eighth '(1 2 3 4 5 6 7 8 9 10 11))
(ninth '(1 2 3 4 5 6 7 8 9 10 11))
(tenth '(1 2 3 4 5 6 7 8 9 10 11))

)
